/*
 * Copyright © 2004-2020 L2J Server
 * 
 * This file is part of L2J Server.
 * 
 * L2J Server is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * L2J Server is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package com.l2jserver.gameserver.model.actor.tasks.attackable;

import static com.l2jserver.gameserver.config.Configuration.character;

import com.l2jserver.gameserver.ThreadPoolManager;
import com.l2jserver.gameserver.model.actor.L2Attackable;

/**
 * @author xban1x
 */
public final class CommandChannelTimer implements Runnable {
	private final L2Attackable _attackable;
	
	public CommandChannelTimer(L2Attackable attackable) {
		_attackable = attackable;
	}
	
	@Override
	public void run() {
		if (_attackable == null) {
			return;
		}
		
		if ((System.currentTimeMillis() - _attackable.getCommandChannelLastAttack()) > character().getRaidLootRightsInterval()) {
			_attackable.setCommandChannelTimer(null);
			_attackable.setFirstCommandChannelAttacked(null);
			_attackable.setCommandChannelLastAttack(0);
		} else {
			ThreadPoolManager.getInstance().scheduleGeneral(this, 10000); // 10sec
		}
	}
}
