/*
 * Copyright © 2004-2020 L2J Server
 *
 * This file is part of L2J Server.
 *
 * L2J Server is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * L2J Server is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package com.l2jserver.gameserver.model.conditions;

import com.l2jserver.gameserver.model.actor.L2Character;
import com.l2jserver.gameserver.model.actor.L2Summon;
import com.l2jserver.gameserver.model.actor.instance.L2PcInstance;
import com.l2jserver.gameserver.model.items.L2Item;
import com.l2jserver.gameserver.model.skills.Skill;
import com.l2jserver.gameserver.network.SystemMessageId;
import com.l2jserver.gameserver.network.serverpackets.SystemMessage;

/**
 * Player Can Resurrect condition implementation.
 * @author UnAfraid
 */
public class ConditionPlayerCanResurrect extends Condition {
	private final boolean _val;
	
	public ConditionPlayerCanResurrect(boolean val) {
		_val = val;
	}
	
	@Override
	public boolean testImpl(L2Character effector, L2Character effected, Skill skill, L2Item item) {
		// Need skill rework for fix that properly
		if (skill.getAffectRange() > 0) {
			return true;
		}
		if (effected == null) {
			return false;
		}
		boolean canResurrect = true;
		
		if (effected.isPlayer()) {
			final L2PcInstance player = effected.getActingPlayer();
			if (!player.isDead()) {
				canResurrect = false;
				if (effector.isPlayer()) {
					final SystemMessage msg = SystemMessage.getSystemMessage(SystemMessageId.S1_CANNOT_BE_USED);
					msg.addSkillName(skill);
					effector.sendPacket(msg);
				}
			} else if (player.isResurrectionBlocked()) {
				canResurrect = false;
				if (effector.isPlayer()) {
					effector.sendPacket(SystemMessageId.REJECT_RESURRECTION);
				}
			} else if (player.isReviveRequested()) {
				canResurrect = false;
				if (effector.isPlayer()) {
					effector.sendPacket(SystemMessageId.RES_HAS_ALREADY_BEEN_PROPOSED);
				}
			}
		} else if (effected.isSummon()) {
			final L2Summon summon = (L2Summon) effected;
			final L2PcInstance player = summon.getOwner();
			if (!summon.isDead()) {
				canResurrect = false;
				if (effector.isPlayer()) {
					final SystemMessage msg = SystemMessage.getSystemMessage(SystemMessageId.S1_CANNOT_BE_USED);
					msg.addSkillName(skill);
					effector.sendPacket(msg);
				}
			} else if (summon.isResurrectionBlocked()) {
				canResurrect = false;
				if (effector.isPlayer()) {
					effector.sendPacket(SystemMessageId.REJECT_RESURRECTION);
				}
			} else if ((player != null) && player.isRevivingPet()) {
				canResurrect = false;
				if (effector.isPlayer()) {
					effector.sendPacket(SystemMessageId.RES_HAS_ALREADY_BEEN_PROPOSED); // Resurrection is already been proposed.
				}
			}
		}
		return (_val == canResurrect);
	}
}