/*
 * Copyright © 2004-2020 L2J Server
 * 
 * This file is part of L2J Server.
 * 
 * L2J Server is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * L2J Server is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package com.l2jserver.gameserver.model.itemcontainer;

import java.util.logging.Level;

import com.l2jserver.commons.database.ConnectionFactory;
import com.l2jserver.gameserver.enums.ItemLocation;
import com.l2jserver.gameserver.idfactory.IdFactory;
import com.l2jserver.gameserver.model.L2World;
import com.l2jserver.gameserver.model.actor.instance.L2PcInstance;
import com.l2jserver.gameserver.model.items.instance.L2ItemInstance;

/**
 * @author DS
 */
public class Mail extends ItemContainer {
	
	private final int _ownerId;
	
	private int _messageId;
	
	public Mail(int objectId, int messageId) {
		_ownerId = objectId;
		_messageId = messageId;
	}
	
	@Override
	public String getName() {
		return "Mail";
	}
	
	@Override
	public L2PcInstance getOwner() {
		return null;
	}
	
	@Override
	public ItemLocation getBaseLocation() {
		return ItemLocation.MAIL;
	}
	
	public int getMessageId() {
		return _messageId;
	}
	
	public void setNewMessageId(int messageId) {
		_messageId = messageId;
		for (L2ItemInstance item : _items) {
			if (item == null) {
				continue;
			}
			
			item.setItemLocation(getBaseLocation(), messageId);
		}
		
		updateDatabase();
	}
	
	public void returnToWh(ItemContainer wh) {
		for (L2ItemInstance item : _items) {
			if (item == null) {
				continue;
			}
			if (wh == null) {
				item.setItemLocation(ItemLocation.WAREHOUSE);
			} else {
				transferItem("Expire", item.getObjectId(), item.getCount(), wh, null, null);
			}
		}
	}
	
	@Override
	protected void addItem(L2ItemInstance item) {
		super.addItem(item);
		item.setItemLocation(getBaseLocation(), _messageId);
	}
	
	@Override
	public void updateDatabase() {
		_items.forEach(i -> i.updateDatabase(true));
	}
	
	@Override
	public void restore() {
		try (var con = ConnectionFactory.getInstance().getConnection();
			var ps = con.prepareStatement("SELECT object_id, item_id, count, enchant_level, loc, loc_data, custom_type1, custom_type2, mana_left, time FROM items WHERE owner_id=? AND loc=? AND loc_data=?")) {
			ps.setInt(1, getOwnerId());
			ps.setString(2, getBaseLocation().name());
			ps.setInt(3, getMessageId());
			try (var rs = ps.executeQuery()) {
				L2ItemInstance item;
				while (rs.next()) {
					item = L2ItemInstance.restoreFromDb(getOwnerId(), rs);
					if (item == null) {
						continue;
					}
					
					L2World.getInstance().storeObject(item);
					
					// If stackable item is found just add to current quantity
					if (item.isStackable() && (getItemByItemId(item.getId()) != null)) {
						addItem("Restore", item, null, null);
					} else {
						addItem(item);
					}
				}
			}
		} catch (Exception e) {
			_log.log(Level.WARNING, "could not restore container:", e);
		}
	}
	
	@Override
	public int getOwnerId() {
		return _ownerId;
	}
	
	@Override
	public void deleteMe() {
		_items.forEach(i -> {
			i.updateDatabase(true);
			i.deleteMe();
			L2World.getInstance().removeObject(i);
			IdFactory.getInstance().releaseId(i.getObjectId());
		});
		_items.clear();
	}
}